@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of MIDI files
 
-our $VERSION = '0.1802';
+our $VERSION = '0.1803';
 
 use Moo;
 use strictures 2;
@@ -662,7 +662,7 @@ MIDI::Ngram - Find the top repeated note phrases of MIDI files
 
 =head1 VERSION
 
-version 0.1802
+version 0.1803
 
 =head1 SYNOPSIS
 
@@ -681,9 +681,11 @@ version 0.1802
   $mng->process;
 
   # Analyze
+  print Dumper $mng->dura_notes;
   print Dumper $mng->duras;
   print Dumper $mng->notes;
 
+  print Dumper $mng->dura_note_net;
   print Dumper $mng->dura_net;
   print Dumper $mng->note_net;
 
@@ -702,7 +704,7 @@ C<MIDI::Ngram> parses a given list of MIDI files, finds the top
 repeated note phrases, builds the transition networks, and renders to
 a MIDI file if desired.
 
-Note: This module currently assumes that all given B<in_files> have
+Note: This module currently assumes that all given B<in_file>s have
 the same MIDI ppqn (given by the first C<$opus-E<gt>ticks> seen).
 
 =head1 ATTRIBUTES
@@ -816,7 +818,7 @@ the B<populate> method.
 The hash-reference bucket of C<duration*note> ngrams.  Constructed by
 the B<process> method.
 
-The combination on duration with a note is indicated with the C<*>
+The combination of duration with a note is indicated with the C<*>
 character.  For example: C<ten*Cs4>
 
 =head2 notes
